/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
/************ Begin %include sections from the grammar ************************/
#line 24 "src/CFCParseHeader.y"

#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdlib.h>
#include "CFC.h"
#include "CFCLexHeader.h"
#ifndef true
  #define true 1
  #define false 0
#endif

static CFCClass*
S_start_class(CFCParser *state, CFCDocuComment *docucomment, char *exposure,
              char *modifiers, char *class_name, char *class_nickname,
              char *inheritance) {
    CFCFileSpec *file_spec = CFCParser_get_file_spec(state);
    int is_final = false;
    int is_inert = false;
    int is_abstract = false;
    if (modifiers) {
        if (strstr(modifiers, "inline")) {
            CFCUtil_die("Illegal class modifiers: '%s'", modifiers);
        }
        is_final = !!strstr(modifiers, "final");
        is_inert = !!strstr(modifiers, "inert");
        is_abstract = !!strstr(modifiers, "abstract");
    }
    CFCParser_set_class_name(state, class_name);
    CFCParser_set_class_final(state, is_final);
    CFCClass *klass = CFCClass_create(CFCParser_get_parcel(state), exposure,
                                      class_name, class_nickname, docucomment,
                                      file_spec, inheritance, is_final,
                                      is_inert, is_abstract);
    CFCBase_decref((CFCBase*)docucomment);
    return klass;
}

static CFCVariable*
S_new_var(char *exposure, char *modifiers, CFCType *type, char *name) {
    int inert = false;
    if (modifiers) {
        if (strcmp(modifiers, "inert") != 0) {
            CFCUtil_die("Illegal variable modifiers: '%s'", modifiers);
        }
        inert = true;
    }

    CFCVariable *var = CFCVariable_new(exposure, name, type, inert);

    /* Consume tokens. */
    CFCBase_decref((CFCBase*)type);

    return var;
}

static CFCBase*
S_new_sub(CFCParser *state, CFCDocuComment *docucomment, 
          char *exposure, char *modifiers, CFCType *type, char *name,
          CFCParamList *param_list) {
    /* Find modifiers by scanning the list. */
    int is_abstract = false;
    int is_final    = false;
    int is_inline   = false;
    int is_inert    = false;
    if (modifiers) {
        is_abstract = !!strstr(modifiers, "abstract");
        is_final    = !!strstr(modifiers, "final");
        is_inline   = !!strstr(modifiers, "inline");
        is_inert    = !!strstr(modifiers, "inert");
    }
    if (CFCParser_get_class_final(state) && !is_inert) {
        is_final = true;
    }

    /* If "inert", it's a function, otherwise it's a method. */
    CFCBase *sub;
    if (is_inert) {
        if (is_abstract) {
            CFCUtil_die("Inert functions must not be abstract");
        }
        if (is_final) {
            CFCUtil_die("Inert functions must not be final");
        }
        sub = (CFCBase*)CFCFunction_new(exposure, name, type, param_list,
                                        docucomment, is_inline);
    }
    else {
        if (is_inline) {
            CFCUtil_die("Methods must not be inline");
        }
        const char *class_name = CFCParser_get_class_name(state);
        sub = (CFCBase*)CFCMethod_new(exposure, name, type, param_list,
                                      docucomment, class_name, is_final,
                                      is_abstract);
    }

    /* Consume tokens. */
    CFCBase_decref((CFCBase*)docucomment);
    CFCBase_decref((CFCBase*)type);
    CFCBase_decref((CFCBase*)param_list);

    return sub;
}

static CFCType*
S_new_type(CFCParser *state, int flags, char *type_name,
           char *asterisk_postfix, char *array_postfix) {
    (void)state; /* unused */
    CFCType *type = NULL;
    size_t type_name_len = strlen(type_name);
    int indirection = asterisk_postfix ? (int)strlen(asterisk_postfix) : 0;

    /* Apply "nullable" to outermost pointer, but "const", etc to innermost
     * type. This is an ugly kludge and the Clownfish header language needs to
     * be fixed, either to support C's terrible pointer type syntax, or to do
     * something better. */
    int composite_flags = 0;
    if (indirection) {
        composite_flags = flags & CFCTYPE_NULLABLE;
        flags &= ~CFCTYPE_NULLABLE;
    }

    if (!strcmp(type_name, "int8_t")
        || !strcmp(type_name, "int16_t")
        || !strcmp(type_name, "int32_t")
        || !strcmp(type_name, "int64_t")
        || !strcmp(type_name, "uint8_t")
        || !strcmp(type_name, "uint16_t")
        || !strcmp(type_name, "uint32_t")
        || !strcmp(type_name, "uint64_t")
        || !strcmp(type_name, "char")
        || !strcmp(type_name, "short")
        || !strcmp(type_name, "int")
        || !strcmp(type_name, "long")
        || !strcmp(type_name, "size_t")
        || !strcmp(type_name, "bool")
       ) {
        type = CFCType_new_integer(flags, type_name);
    }
    else if (!strcmp(type_name, "float")
             || !strcmp(type_name, "double")
            ) {
        type = CFCType_new_float(flags, type_name);
    }
    else if (!strcmp(type_name, "void")) {
        type = CFCType_new_void(!!(flags & CFCTYPE_CONST));
    }
    else if (!strcmp(type_name, "va_list")) {
        type = CFCType_new_va_list();
    }
    else if (type_name_len > 2
             && !strcmp(type_name + type_name_len - 2, "_t")
            ) {
        type = CFCType_new_arbitrary(CFCParser_get_parcel(state), type_name);
    }
    else if (indirection > 0) {
        /* The only remaining possibility is an object type, and we can let
         * the constructor perform the complex validation of the type name. */
        indirection--;
        if (indirection == 0) {
            flags |= composite_flags;
            composite_flags = 0;
        }
        type = CFCType_new_object(flags, CFCParser_get_parcel(state), type_name, 1);
    }
    else {
        CFCUtil_die("Invalid type specification at/near '%s'", type_name);
    }

    if (indirection) {
        CFCType *composite = CFCType_new_composite(composite_flags, type,
                                                   indirection, NULL);
        CFCBase_decref((CFCBase*)type);
        type = composite;
    }
    else if (array_postfix) {
        CFCType *composite = CFCType_new_composite(composite_flags, type,
                                                   0, array_postfix);
        CFCBase_decref((CFCBase*)type);
        type = composite;
    }

    return type;
}

#line 215 "src/CFCParseHeader.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    CFCParseHeaderTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is CFCParseHeaderTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    CFCParseHeaderARG_SDECL     A static variable declaration for the %extra_argument
**    CFCParseHeaderARG_PDECL     A parameter declaration for the %extra_argument
**    CFCParseHeaderARG_STORE     Code to store %extra_argument into yypParser
**    CFCParseHeaderARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYNTOKEN           Number of terminal symbols
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
**    YY_MIN_REDUCE      Minimum value for reduce actions
**    YY_MAX_REDUCE      Maximum value for reduce actions
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned char
#define YYNOCODE 75
#define YYACTIONTYPE unsigned short int
#define CFCParseHeaderTOKENTYPE char*
typedef union {
  int yyinit;
  CFCParseHeaderTOKENTYPE yy0;
  int yy8;
  CFCParcel* yy14;
  CFCType* yy41;
  CFCFile* yy51;
  CFCVariable* yy57;
  CFCDocuComment* yy73;
  CFCBase* yy82;
  CFCParamList* yy96;
  CFCCBlock* yy117;
  CFCClass* yy141;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define CFCParseHeaderARG_SDECL  CFCParser *state ;
#define CFCParseHeaderARG_PDECL , CFCParser *state 
#define CFCParseHeaderARG_FETCH  CFCParser *state  = yypParser->state 
#define CFCParseHeaderARG_STORE yypParser->state  = state 
#define YYNSTATE             191
#define YYNRULE              117
#define YYNTOKEN             43
#define YY_MAX_SHIFT         190
#define YY_MIN_SHIFTREDUCE   191
#define YY_MAX_SHIFTREDUCE   307
#define YY_ERROR_ACTION      308
#define YY_ACCEPT_ACTION     309
#define YY_NO_ACTION         310
#define YY_MIN_REDUCE        311
#define YY_MAX_REDUCE        427
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X.
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1195)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   141,   56,   55,  127,   39,   57,  128,  123,  122,  121,
 /*    10 */   120,  119,   95,  115,  114,  113,  112,  101,  100,   99,
 /*    20 */    98,  123,  122,  121,  120,  119,  111,  115,  114,  113,
 /*    30 */   112,    9,  134,   40,   20,  128,   97,   92,  309,    2,
 /*    40 */    42,  171,  167,  155,    1,  169,  168,   54,  186,  187,
 /*    50 */   142,    3,  170,  110,   22,  130,    5,   10,  368,   43,
 /*    60 */   156,   21,  368,  190,   96,  368,  368,  368,  368,  368,
 /*    70 */   368,  368,  368,  368,  368,  368,  368,  368,  368,  123,
 /*    80 */   122,  121,  120,  119,   95,  115,  114,  113,  112,  101,
 /*    90 */   100,   99,   98,   24,   37,  368,  367,   44,  158,  138,
 /*   100 */   367,   96,  102,  367,  367,  367,  367,  367,  367,  367,
 /*   110 */   367,  367,  367,  367,  367,  367,  367,   59,  157,  123,
 /*   120 */   122,  121,  120,  119,  350,  115,  114,  113,  112,  101,
 /*   130 */   100,   99,   98,  367,  364,  184,  417,  417,  364,   33,
 /*   140 */   159,  364,  364,  364,  364,  364,  364,  364,  364,  364,
 /*   150 */   364,  364,  364,  364,  364,   74,   77,  123,  122,  121,
 /*   160 */   120,  119,  346,  115,  114,  113,  112,  101,  100,   99,
 /*   170 */    98,  364,  366,  161,  415,  415,  366,   34,  163,  366,
 /*   180 */   366,  366,  366,  366,  366,  366,  366,  366,  366,  366,
 /*   190 */   366,  366,  366,   58,   77,  123,  122,  121,  120,  119,
 /*   200 */   348,  115,  114,  113,  112,  101,  100,   99,   98,  366,
 /*   210 */   363,  174,  411,  411,  363,  411,  165,  363,  363,  363,
 /*   220 */   363,  363,  363,  363,  363,  363,  363,  363,  363,  363,
 /*   230 */   363,   60,   77,  123,  122,  121,  120,  119,  344,  115,
 /*   240 */   114,  113,  112,  101,  100,   99,   98,  363,  369,   45,
 /*   250 */   160,  166,  369,   46,  162,  369,  369,  369,  369,  369,
 /*   260 */   369,  369,  369,  369,  369,  369,  369,  369,  369,   71,
 /*   270 */    77,  123,  122,  121,  120,  119,  349,  115,  114,  113,
 /*   280 */   112,  101,  100,   99,   98,  369,  370,   50,  173,  177,
 /*   290 */   370,   51,  176,  370,  370,  370,  370,  370,  370,  370,
 /*   300 */   370,  370,  370,  370,  370,  370,  370,   78,   77,  123,
 /*   310 */   122,  121,  120,  119,  345,  115,  114,  113,  112,  101,
 /*   320 */   100,   99,   98,  370,  372,   52,  179,  180,  372,   53,
 /*   330 */   183,  372,  372,  372,  372,  372,  372,  372,  372,  372,
 /*   340 */   372,  372,  372,  372,  372,  384,   77,  384,  384,  384,
 /*   350 */   384,  384,  347,  384,  384,  384,  384,  384,  384,  384,
 /*   360 */   384,  372,  371,  104,  136,  185,  371,  426,  426,  371,
 /*   370 */   371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
 /*   380 */   371,  371,  371,  395,   77,  395,  395,  395,  395,  395,
 /*   390 */   343,  395,  395,  395,  395,  395,  395,  395,  395,  371,
 /*   400 */   365,  427,  427,   41,  365,  105,  137,  365,  365,  365,
 /*   410 */   365,  365,  365,  365,  365,  365,  365,  365,  365,  365,
 /*   420 */   365,  396,   77,  396,  396,  396,  396,  396,  311,  396,
 /*   430 */   396,  396,  396,  396,  396,  396,  396,  365,  362,  116,
 /*   440 */   418,  418,  362,  416,  416,  362,  362,  362,  362,  362,
 /*   450 */   362,  362,  362,  362,  362,  362,  362,  362,  362,  394,
 /*   460 */   135,  394,  394,  394,  394,  394,  423,  394,  394,  394,
 /*   470 */   394,  394,  394,  394,  394,  362,   82,  409,  409,  118,
 /*   480 */   106,  408,  408,  123,  122,  121,  120,  119,   95,  115,
 /*   490 */   114,  113,  112,  101,  100,   99,   98,  393,  423,  393,
 /*   500 */   393,  393,  393,  393,    9,  393,  393,  393,  393,  393,
 /*   510 */   393,  393,  393,   92,  314,  407,  407,  406,  406,   68,
 /*   520 */    55,  123,  122,  121,  120,  119,   95,  115,  114,  113,
 /*   530 */   112,  101,  100,   99,   98,  359,  405,  405,  359,  359,
 /*   540 */   359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
 /*   550 */   359,  359,  392,  103,  392,  392,  392,  392,  392,   25,
 /*   560 */   392,  392,  392,  392,  392,  392,  392,  392,  359,  421,
 /*   570 */   404,  404,  403,  403,  421,    9,  421,  421,  421,  421,
 /*   580 */   421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
 /*   590 */   361,  151,   18,  361,  361,  361,  361,  361,  361,  361,
 /*   600 */   361,  361,  361,  361,  361,  361,  361,  391,   61,  391,
 /*   610 */   391,  391,  391,  391,   26,  391,  391,  391,  391,  391,
 /*   620 */   391,  391,  391,  361,  132,  189,   27,   28,  360,  164,
 /*   630 */   116,  360,  360,  360,  360,  360,  360,  360,  360,  360,
 /*   640 */   360,  360,  360,  360,  360,  123,  122,  121,  120,  119,
 /*   650 */    47,  115,  114,  113,  112,  101,  100,   99,   98,   36,
 /*   660 */    38,  360,   94,   93,   65,  378,   96,   96,    4,   48,
 /*   670 */   110,   22,  411,    8,   17,   90,  378,  420,   21,   49,
 /*   680 */   420,   96,  123,  122,  121,  120,  119,  154,  115,  114,
 /*   690 */   113,  112,  123,  122,  121,  120,  119,  320,  115,  114,
 /*   700 */   113,  112,   57,    9,  172,   84,  422,  153,  414,   95,
 /*   710 */   420,  414,  420,  420,  101,  100,   99,   98,   90,  188,
 /*   720 */   147,  149,  148,  146,  145,  144,  143,   66,  109,   29,
 /*   730 */   108,  155,    1,    9,   92,  175,  184,   42,  325,   19,
 /*   740 */   107,   91,   69,  325,   23,   35,    9,   30,  178,   72,
 /*   750 */   325,  413,   96,   31,  413,  325,  325,  325,  325,  181,
 /*   760 */   389,  389,  389,  389,  389,   75,  389,  389,  389,  389,
 /*   770 */   140,   32,  126,   67,  412,  325,  321,  412,  325,  110,
 /*   780 */    22,  321,    6,   12,  342,   68,  319,   21,  321,  334,
 /*   790 */    96,  338,   95,  321,  321,  321,  321,  101,  100,   99,
 /*   800 */    98,  390,  390,  390,  390,  390,  330,  390,  390,  390,
 /*   810 */   390,   67,  340,  321,  425,  332,  321,  110,   22,  425,
 /*   820 */     7,   15,  336,   79,  125,   21,  425,  328,   96,  110,
 /*   830 */    22,  425,  425,  425,  425,  358,   80,   21,   81,  388,
 /*   840 */   388,  388,  388,  388,   83,  388,  388,  388,  388,   62,
 /*   850 */   318,  425,  424,  317,  425,  110,   22,  424,  316,   11,
 /*   860 */   315,   59,   85,   21,  424,  184,   96,   77,  182,  424,
 /*   870 */   424,  424,  424,  101,  100,   99,   98,  387,  387,  387,
 /*   880 */   387,  387,  341,  387,  387,  387,  387,   73,  333,  424,
 /*   890 */   326,   86,  424,  110,   22,  326,   87,   13,  337,   74,
 /*   900 */   139,   21,  326,  339,   96,  329,  331,  326,  326,  326,
 /*   910 */   326,  101,  100,   99,   98,  386,  386,  386,  386,  386,
 /*   920 */    88,  386,  386,  386,  386,   73,  335,  326,  324,  117,
 /*   930 */   326,  110,   22,  324,  150,   14,  327,   58,  313,   21,
 /*   940 */   324,  312,   96,   89,  131,  324,  324,  324,  324,  101,
 /*   950 */   100,   99,   98,  385,  385,  385,  385,  385,  310,  385,
 /*   960 */   385,  385,  385,   62,  410,  324,  323,  410,  324,  110,
 /*   970 */    22,  323,  310,   16,  310,   64,  310,   21,  323,  310,
 /*   980 */    96,  110,   22,  323,  323,  323,  323,   79,  124,   21,
 /*   990 */   152,  377,   97,  110,   22,  410,  410,  410,  310,  410,
 /*  1000 */   310,   21,  377,  323,  322,  310,  323,  310,  310,  322,
 /*  1010 */   310,   63,  133,   70,  310,  310,  322,  110,   22,  110,
 /*  1020 */    22,  322,  322,  322,  322,   21,  310,   21,   97,   76,
 /*  1030 */    97,  310,  310,  310,  310,  110,   22,  310,  310,  310,
 /*  1040 */   310,  322,   60,   21,  322,  310,   97,   71,  419,  310,
 /*  1050 */   310,  419,   78,  310,  101,  100,   99,   98,  376,  101,
 /*  1060 */   100,   99,   98,  375,  101,  100,   99,   98,  354,  376,
 /*  1070 */   310,  310,  310,  310,  375,  356,  310,  310,  310,  129,
 /*  1080 */   154,  419,  373,  419,  419,  154,  352,  310,  310,  310,
 /*  1090 */   357,  310,  310,  373,  310,  310,  310,  353,  184,  310,
 /*  1100 */    77,  182,  401,  129,  154,  184,  310,   77,  182,  310,
 /*  1110 */   355,  310,  310,  401,  351,  383,  184,  382,   77,  182,
 /*  1120 */   184,  310,   77,  182,  401,  310,  383,  184,  382,   77,
 /*  1130 */   182,  310,  310,  310,  310,  310,  383,  383,  382,  382,
 /*  1140 */   184,  381,   77,  182,  184,  380,   77,  182,  379,  402,
 /*  1150 */   400,  310,  381,  397,  399,  310,  380,  398,  310,  379,
 /*  1160 */   402,  400,  381,  381,  397,  399,  380,  380,  398,  379,
 /*  1170 */   379,  402,  400,  374,  397,  310,  399,  310,  398,  310,
 /*  1180 */   310,  310,  310,  310,  374,  310,  310,  310,  310,  310,
 /*  1190 */   310,  310,  310,  310,  133,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    72,    1,    2,   68,   69,    5,   71,    7,    8,    9,
 /*    10 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*    20 */    20,    7,    8,    9,   10,   11,   59,   13,   14,   15,
 /*    30 */    16,   31,   68,   69,   67,   71,   70,   37,   44,   45,
 /*    40 */    40,   47,   48,   49,   50,   51,   52,   53,   54,   55,
 /*    50 */    72,   57,   58,   59,   60,   71,   62,   63,    0,   64,
 /*    60 */    65,   67,    4,   55,   70,    7,    8,    9,   10,   11,
 /*    70 */    12,   13,   14,   15,   16,   17,   18,   19,   20,    7,
 /*    80 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    90 */    18,   19,   20,   62,   63,   37,    0,   64,   65,   73,
 /*   100 */     4,   70,    3,    7,    8,    9,   10,   11,   12,   13,
 /*   110 */    14,   15,   16,   17,   18,   19,   20,    5,   65,    7,
 /*   120 */     8,    9,   10,   11,    6,   13,   14,   15,   16,   17,
 /*   130 */    18,   19,   20,   37,    0,   36,   32,   33,    4,   35,
 /*   140 */    65,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   150 */    16,   17,   18,   19,   20,    5,   38,    7,    8,    9,
 /*   160 */    10,   11,    6,   13,   14,   15,   16,   17,   18,   19,
 /*   170 */    20,   37,    0,   65,   32,   33,    4,   35,   65,    7,
 /*   180 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   190 */    18,   19,   20,    5,   38,    7,    8,    9,   10,   11,
 /*   200 */     6,   13,   14,   15,   16,   17,   18,   19,   20,   37,
 /*   210 */     0,   65,   32,   33,    4,   35,   55,    7,    8,    9,
 /*   220 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   230 */    20,    5,   38,    7,    8,    9,   10,   11,    6,   13,
 /*   240 */    14,   15,   16,   17,   18,   19,   20,   37,    0,   64,
 /*   250 */    65,   55,    4,   64,   65,    7,    8,    9,   10,   11,
 /*   260 */    12,   13,   14,   15,   16,   17,   18,   19,   20,    5,
 /*   270 */    38,    7,    8,    9,   10,   11,    6,   13,   14,   15,
 /*   280 */    16,   17,   18,   19,   20,   37,    0,   64,   65,   65,
 /*   290 */     4,   64,   65,    7,    8,    9,   10,   11,   12,   13,
 /*   300 */    14,   15,   16,   17,   18,   19,   20,    5,   38,    7,
 /*   310 */     8,    9,   10,   11,    6,   13,   14,   15,   16,   17,
 /*   320 */    18,   19,   20,   37,    0,   64,   65,   65,    4,   64,
 /*   330 */    65,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   340 */    16,   17,   18,   19,   20,    5,   38,    7,    8,    9,
 /*   350 */    10,   11,    6,   13,   14,   15,   16,   17,   18,   19,
 /*   360 */    20,   37,    0,   41,   42,   65,    4,   41,   42,    7,
 /*   370 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   380 */    18,   19,   20,    5,   38,    7,    8,    9,   10,   11,
 /*   390 */     6,   13,   14,   15,   16,   17,   18,   19,   20,   37,
 /*   400 */     0,   41,   42,   66,    4,   41,   42,    7,    8,    9,
 /*   410 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   420 */    20,    5,   38,    7,    8,    9,   10,   11,    0,   13,
 /*   430 */    14,   15,   16,   17,   18,   19,   20,   37,    0,   11,
 /*   440 */    32,   33,    4,   32,   33,    7,    8,    9,   10,   11,
 /*   450 */    12,   13,   14,   15,   16,   17,   18,   19,   20,    5,
 /*   460 */    61,    7,    8,    9,   10,   11,    6,   13,   14,   15,
 /*   470 */    16,   17,   18,   19,   20,   37,    3,   32,   33,   11,
 /*   480 */     4,   32,   33,    7,    8,    9,   10,   11,   12,   13,
 /*   490 */    14,   15,   16,   17,   18,   19,   20,    5,   38,    7,
 /*   500 */     8,    9,   10,   11,   31,   13,   14,   15,   16,   17,
 /*   510 */    18,   19,   20,   37,    0,   32,   33,   32,   33,    5,
 /*   520 */     2,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   530 */    16,   17,   18,   19,   20,    4,   32,   33,    7,    8,
 /*   540 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   550 */    19,   20,    5,   47,    7,    8,    9,   10,   11,   61,
 /*   560 */    13,   14,   15,   16,   17,   18,   19,   20,   37,    0,
 /*   570 */    32,   33,   32,   33,    5,   31,    7,    8,    9,   10,
 /*   580 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   590 */     4,   32,   33,    7,    8,    9,   10,   11,   12,   13,
 /*   600 */    14,   15,   16,   17,   18,   19,   20,    5,   66,    7,
 /*   610 */     8,    9,   10,   11,   61,   13,   14,   15,   16,   17,
 /*   620 */    18,   19,   20,   37,   23,   24,   61,   61,    4,   55,
 /*   630 */    11,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   640 */    16,   17,   18,   19,   20,    7,    8,    9,   10,   11,
 /*   650 */    66,   13,   14,   15,   16,   17,   18,   19,   20,   63,
 /*   660 */    63,   37,   51,   52,   53,    0,   70,   70,   57,   66,
 /*   670 */    59,   60,    0,   62,   63,    3,   11,    3,   67,   66,
 /*   680 */     6,   70,    7,    8,    9,   10,   11,   22,   13,   14,
 /*   690 */    15,   16,    7,    8,    9,   10,   11,    0,   13,   14,
 /*   700 */    15,   16,    5,   31,   55,    3,    6,   32,    0,   12,
 /*   710 */    36,    3,   38,   39,   17,   18,   19,   20,    3,   34,
 /*   720 */    24,   25,   26,   27,   28,   29,   30,   66,   46,   61,
 /*   730 */    48,   49,   50,   31,   37,   55,   36,   40,    0,   57,
 /*   740 */    58,    6,   66,    5,   62,   63,   31,   61,   55,   66,
 /*   750 */    12,    0,   70,   61,    3,   17,   18,   19,   20,   55,
 /*   760 */     7,    8,    9,   10,   11,   66,   13,   14,   15,   16,
 /*   770 */    61,   61,   66,   53,    0,   37,    0,    3,   40,   59,
 /*   780 */    60,    5,   62,   63,    6,    5,    0,   67,   12,    6,
 /*   790 */    70,    6,   12,   17,   18,   19,   20,   17,   18,   19,
 /*   800 */    20,    7,    8,    9,   10,   11,    6,   13,   14,   15,
 /*   810 */    16,   53,    6,   37,    0,    6,   40,   59,   60,    5,
 /*   820 */    62,   63,    6,   53,   54,   67,   12,    6,   70,   59,
 /*   830 */    60,   17,   18,   19,   20,    6,    3,   67,    3,    7,
 /*   840 */     8,    9,   10,   11,    3,   13,   14,   15,   16,   53,
 /*   850 */     0,   37,    0,    0,   40,   59,   60,    5,    0,   63,
 /*   860 */     0,    5,    3,   67,   12,   36,   70,   38,   39,   17,
 /*   870 */    18,   19,   20,   17,   18,   19,   20,    7,    8,    9,
 /*   880 */    10,   11,    6,   13,   14,   15,   16,   53,    6,   37,
 /*   890 */     0,    3,   40,   59,   60,    5,    3,   63,    6,    5,
 /*   900 */    11,   67,   12,    6,   70,    6,    6,   17,   18,   19,
 /*   910 */    20,   17,   18,   19,   20,    7,    8,    9,   10,   11,
 /*   920 */     3,   13,   14,   15,   16,   53,    6,   37,    0,   11,
 /*   930 */    40,   59,   60,    5,   32,   63,    6,    5,    0,   67,
 /*   940 */    12,    0,   70,    3,   23,   17,   18,   19,   20,   17,
 /*   950 */    18,   19,   20,    7,    8,    9,   10,   11,   74,   13,
 /*   960 */    14,   15,   16,   53,    0,   37,    0,    3,   40,   59,
 /*   970 */    60,    5,   74,   63,   74,   53,   74,   67,   12,   74,
 /*   980 */    70,   59,   60,   17,   18,   19,   20,   53,   54,   67,
 /*   990 */    56,    0,   70,   59,   60,   31,   32,   33,   74,   35,
 /*  1000 */    74,   67,   11,   37,    0,   74,   40,   74,   74,    5,
 /*  1010 */    74,   53,   21,   53,   74,   74,   12,   59,   60,   59,
 /*  1020 */    60,   17,   18,   19,   20,   67,   74,   67,   70,   53,
 /*  1030 */    70,   74,   74,   74,   74,   59,   60,   74,   74,   74,
 /*  1040 */    74,   37,    5,   67,   40,   74,   70,    5,    3,   74,
 /*  1050 */    74,    6,    5,   74,   17,   18,   19,   20,    0,   17,
 /*  1060 */    18,   19,   20,    0,   17,   18,   19,   20,    6,   11,
 /*  1070 */    74,   74,   74,   74,   11,    6,   74,   74,   74,   21,
 /*  1080 */    22,   36,    0,   38,   39,   22,    6,   74,   74,   74,
 /*  1090 */     6,   74,   74,   11,   74,   74,   74,    6,   36,   74,
 /*  1100 */    38,   39,    0,   21,   22,   36,   74,   38,   39,   74,
 /*  1110 */     6,   74,   74,   11,    6,    0,   36,    0,   38,   39,
 /*  1120 */    36,   74,   38,   39,   22,   74,   11,   36,   11,   38,
 /*  1130 */    39,   74,   74,   74,   74,   74,   21,   22,   21,   22,
 /*  1140 */    36,    0,   38,   39,   36,    0,   38,   39,    0,    0,
 /*  1150 */     0,   74,   11,    0,    0,   74,   11,    0,   74,   11,
 /*  1160 */    11,   11,   21,   22,   11,   11,   21,   22,   11,   21,
 /*  1170 */    22,   22,   22,    0,   21,   74,   22,   74,   21,   74,
 /*  1180 */    74,   74,   74,   74,   11,   74,   74,   74,   74,   74,
 /*  1190 */    74,   74,   74,   74,   21,   74,   74,   74,   74,   74,
 /*  1200 */    74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
 /*  1210 */    74,   74,   74,   74,   74,   74,   74,
};
#define YY_SHIFT_COUNT    (190)
#define YY_SHIFT_MIN      (0)
#define YY_SHIFT_MAX      (1173)
static const unsigned short int yy_shift_ofst[] = {
 /*     0 */     0,  476,  697,  514,   72,  112,  150,  638,  638,  675,
 /*    10 */   188,  226,  264,  302,  638,  638,  638,  638,  685,  780,
 /*    20 */  1058, 1082,   14,  856,  894,  829, 1062, 1069, 1080, 1084,
 /*    30 */  1091, 1104, 1108,  696,  696,  932, 1037, 1042, 1047,  665,
 /*    40 */  1063,  672,  322,  118,  156,  194,  232,  473,  702,  715,
 /*    50 */   270,  308,  346,  384,  428,  468,  518,  468,  468,  468,
 /*    60 */   468,  544,  619,  619,  619,  619,  544,  619,  468,  544,
 /*    70 */   619,  468,  544,  619,  468,  544,  619,  468,  468,  619,
 /*    80 */    58,   96,  134,  172,  210,  248,  286,  324,  362,  400,
 /*    90 */   438,  531,  569,  586,  624,  340,  378,  416,  454,  492,
 /*   100 */   547,  602,  738,  776,  814,  852,  890,  928,  966, 1004,
 /*   110 */   753,  794,  832,  870,  908,  946,  964,  674, 1045, 1115,
 /*   120 */  1117, 1141, 1145, 1148,  104,  142,  180,  991, 1102, 1153,
 /*   130 */  1149, 1150, 1154, 1157, 1173,   99,  326,  360,  364,  460,
 /*   140 */   700,  408,  411,  445,  449,  483,  485,  504,  538,  540,
 /*   150 */   708,  751,  559,  774,  601,  735,  778,  783,  785,  800,
 /*   160 */   806,  809,  816,  821,  833,  835,  841,  786,  850,  853,
 /*   170 */   858,  860,  859,  876,  882,  888,  892,  899,  893,  897,
 /*   180 */   900,  917,  889,  920,  918,  930,  938,  941,  902,  921,
 /*   190 */   940,
};
#define YY_REDUCE_COUNT (79)
#define YY_REDUCE_MIN   (-72)
#define YY_REDUCE_MAX   (976)
static const short yy_reduce_ofst[] = {
 /*     0 */    -6,  611,  682,  720,  758,  796,  834,  872,  910,  934,
 /*    10 */   922,  958,  960,  976,  976,  960,  958,  922,  770,   31,
 /*    20 */   -65,  -36,  -33,  596,  597,   -5,   33,  185,  189,  223,
 /*    30 */   227,  261,  265,  -72,  -22,  -34,  -34,  -34,  -34,  -16,
 /*    40 */   -16,    8,   26,   53,   75,  108,  113,  161,  196,    8,
 /*    50 */   146,  224,  262,  300,  337,  399,  506,  498,  553,  565,
 /*    60 */   566,  574,  542,  584,  603,  613,  649,  661,  668,  680,
 /*    70 */   676,  686,  693,  683,  692,  704,  699,  709,  710,  706,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    10 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    20 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    30 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    40 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    50 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    60 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    70 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    80 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    90 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   100 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   110 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   120 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   130 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   140 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   150 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   160 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   170 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   180 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   190 */   308,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  CFCParseHeaderARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
  yyStackEntry *yystackEnd;            /* Last entry in the stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void CFCParseHeaderTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#if defined(YYCOVERAGE) || !defined(NDEBUG)
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  /*    0 */ "$",
  /*    1 */ "FILE_START",
  /*    2 */ "PARCEL",
  /*    3 */ "SEMICOLON",
  /*    4 */ "RIGHT_CURLY_BRACE",
  /*    5 */ "CLASS",
  /*    6 */ "LEFT_CURLY_BRACE",
  /*    7 */ "VOID",
  /*    8 */ "VA_LIST",
  /*    9 */ "INTEGER_TYPE_NAME",
  /*   10 */ "FLOAT_TYPE_NAME",
  /*   11 */ "IDENTIFIER",
  /*   12 */ "PUBLIC",
  /*   13 */ "CONST",
  /*   14 */ "NULLABLE",
  /*   15 */ "INCREMENTED",
  /*   16 */ "DECREMENTED",
  /*   17 */ "INERT",
  /*   18 */ "INLINE",
  /*   19 */ "ABSTRACT",
  /*   20 */ "FINAL",
  /*   21 */ "ASTERISK",
  /*   22 */ "LEFT_SQUARE_BRACKET",
  /*   23 */ "RIGHT_SQUARE_BRACKET",
  /*   24 */ "INTEGER_LITERAL",
  /*   25 */ "HEX_LITERAL",
  /*   26 */ "FLOAT_LITERAL",
  /*   27 */ "STRING_LITERAL",
  /*   28 */ "TRUE",
  /*   29 */ "FALSE",
  /*   30 */ "NULL",
  /*   31 */ "LEFT_PAREN",
  /*   32 */ "RIGHT_PAREN",
  /*   33 */ "COMMA",
  /*   34 */ "ELLIPSIS",
  /*   35 */ "EQUALS",
  /*   36 */ "SCOPE_OP",
  /*   37 */ "DOCUCOMMENT",
  /*   38 */ "INHERITS",
  /*   39 */ "NICKNAME",
  /*   40 */ "CBLOCK_START",
  /*   41 */ "CBLOCK_CLOSE",
  /*   42 */ "BLOB",
  /*   43 */ "error",
  /*   44 */ "result",
  /*   45 */ "file",
  /*   46 */ "major_block",
  /*   47 */ "parcel_definition",
  /*   48 */ "class_declaration",
  /*   49 */ "class_head",
  /*   50 */ "class_defs",
  /*   51 */ "var_declaration_statement",
  /*   52 */ "subroutine_declaration_statement",
  /*   53 */ "type",
  /*   54 */ "param_variable",
  /*   55 */ "param_list",
  /*   56 */ "param_list_elems",
  /*   57 */ "docucomment",
  /*   58 */ "cblock",
  /*   59 */ "type_qualifier",
  /*   60 */ "type_qualifier_list",
  /*   61 */ "qualified_id",
  /*   62 */ "exposure_specifier",
  /*   63 */ "declaration_modifier_list",
  /*   64 */ "nickname",
  /*   65 */ "class_inheritance",
  /*   66 */ "declarator",
  /*   67 */ "type_name",
  /*   68 */ "asterisk_postfix",
  /*   69 */ "array_postfix",
  /*   70 */ "declaration_modifier",
  /*   71 */ "array_postfix_elem",
  /*   72 */ "scalar_constant",
  /*   73 */ "blob",
};
#endif /* defined(YYCOVERAGE) || !defined(NDEBUG) */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "result ::= type",
 /*   1 */ "result ::= param_list",
 /*   2 */ "result ::= param_variable",
 /*   3 */ "result ::= docucomment",
 /*   4 */ "result ::= parcel_definition",
 /*   5 */ "result ::= cblock",
 /*   6 */ "result ::= var_declaration_statement",
 /*   7 */ "result ::= subroutine_declaration_statement",
 /*   8 */ "result ::= class_declaration",
 /*   9 */ "result ::= file",
 /*  10 */ "file ::= FILE_START parcel_definition",
 /*  11 */ "file ::= file major_block",
 /*  12 */ "major_block ::= class_declaration",
 /*  13 */ "major_block ::= cblock",
 /*  14 */ "parcel_definition ::= PARCEL qualified_id SEMICOLON",
 /*  15 */ "class_declaration ::= class_defs RIGHT_CURLY_BRACE",
 /*  16 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  17 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  18 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  19 */ "class_head ::= declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  20 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id nickname class_inheritance",
 /*  21 */ "class_head ::= exposure_specifier CLASS qualified_id nickname class_inheritance",
 /*  22 */ "class_head ::= docucomment CLASS qualified_id nickname class_inheritance",
 /*  23 */ "class_head ::= CLASS qualified_id nickname class_inheritance",
 /*  24 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  25 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  26 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  27 */ "class_head ::= declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  28 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id class_inheritance",
 /*  29 */ "class_head ::= exposure_specifier CLASS qualified_id class_inheritance",
 /*  30 */ "class_head ::= docucomment CLASS qualified_id class_inheritance",
 /*  31 */ "class_head ::= CLASS qualified_id class_inheritance",
 /*  32 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname",
 /*  33 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname",
 /*  34 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname",
 /*  35 */ "class_head ::= declaration_modifier_list CLASS qualified_id nickname",
 /*  36 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id nickname",
 /*  37 */ "class_head ::= exposure_specifier CLASS qualified_id nickname",
 /*  38 */ "class_head ::= docucomment CLASS qualified_id nickname",
 /*  39 */ "class_head ::= CLASS qualified_id nickname",
 /*  40 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id",
 /*  41 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id",
 /*  42 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id",
 /*  43 */ "class_head ::= declaration_modifier_list CLASS qualified_id",
 /*  44 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id",
 /*  45 */ "class_head ::= exposure_specifier CLASS qualified_id",
 /*  46 */ "class_head ::= docucomment CLASS qualified_id",
 /*  47 */ "class_head ::= CLASS qualified_id",
 /*  48 */ "class_defs ::= class_head LEFT_CURLY_BRACE",
 /*  49 */ "class_defs ::= class_defs var_declaration_statement",
 /*  50 */ "class_defs ::= class_defs subroutine_declaration_statement",
 /*  51 */ "var_declaration_statement ::= type declarator SEMICOLON",
 /*  52 */ "var_declaration_statement ::= declaration_modifier_list type declarator SEMICOLON",
 /*  53 */ "var_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator SEMICOLON",
 /*  54 */ "subroutine_declaration_statement ::= type declarator param_list SEMICOLON",
 /*  55 */ "subroutine_declaration_statement ::= declaration_modifier_list type declarator param_list SEMICOLON",
 /*  56 */ "subroutine_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON",
 /*  57 */ "subroutine_declaration_statement ::= exposure_specifier type declarator param_list SEMICOLON",
 /*  58 */ "subroutine_declaration_statement ::= docucomment type declarator param_list SEMICOLON",
 /*  59 */ "subroutine_declaration_statement ::= docucomment declaration_modifier_list type declarator param_list SEMICOLON",
 /*  60 */ "subroutine_declaration_statement ::= docucomment exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON",
 /*  61 */ "subroutine_declaration_statement ::= docucomment exposure_specifier type declarator param_list SEMICOLON",
 /*  62 */ "type ::= type_name",
 /*  63 */ "type ::= type_name asterisk_postfix",
 /*  64 */ "type ::= type_name array_postfix",
 /*  65 */ "type ::= type_qualifier_list type_name",
 /*  66 */ "type ::= type_qualifier_list type_name asterisk_postfix",
 /*  67 */ "type ::= type_qualifier_list type_name array_postfix",
 /*  68 */ "type_name ::= VOID",
 /*  69 */ "type_name ::= VA_LIST",
 /*  70 */ "type_name ::= INTEGER_TYPE_NAME",
 /*  71 */ "type_name ::= FLOAT_TYPE_NAME",
 /*  72 */ "type_name ::= IDENTIFIER",
 /*  73 */ "exposure_specifier ::= PUBLIC",
 /*  74 */ "type_qualifier ::= CONST",
 /*  75 */ "type_qualifier ::= NULLABLE",
 /*  76 */ "type_qualifier ::= INCREMENTED",
 /*  77 */ "type_qualifier ::= DECREMENTED",
 /*  78 */ "type_qualifier_list ::= type_qualifier",
 /*  79 */ "type_qualifier_list ::= type_qualifier_list type_qualifier",
 /*  80 */ "declaration_modifier ::= INERT",
 /*  81 */ "declaration_modifier ::= INLINE",
 /*  82 */ "declaration_modifier ::= ABSTRACT",
 /*  83 */ "declaration_modifier ::= FINAL",
 /*  84 */ "declaration_modifier_list ::= declaration_modifier",
 /*  85 */ "declaration_modifier_list ::= declaration_modifier_list declaration_modifier",
 /*  86 */ "asterisk_postfix ::= ASTERISK",
 /*  87 */ "asterisk_postfix ::= asterisk_postfix ASTERISK",
 /*  88 */ "array_postfix_elem ::= LEFT_SQUARE_BRACKET RIGHT_SQUARE_BRACKET",
 /*  89 */ "array_postfix_elem ::= LEFT_SQUARE_BRACKET INTEGER_LITERAL RIGHT_SQUARE_BRACKET",
 /*  90 */ "array_postfix ::= array_postfix_elem",
 /*  91 */ "array_postfix ::= array_postfix array_postfix_elem",
 /*  92 */ "scalar_constant ::= HEX_LITERAL",
 /*  93 */ "scalar_constant ::= FLOAT_LITERAL",
 /*  94 */ "scalar_constant ::= INTEGER_LITERAL",
 /*  95 */ "scalar_constant ::= STRING_LITERAL",
 /*  96 */ "scalar_constant ::= TRUE",
 /*  97 */ "scalar_constant ::= FALSE",
 /*  98 */ "scalar_constant ::= NULL",
 /*  99 */ "declarator ::= IDENTIFIER",
 /* 100 */ "param_variable ::= type declarator",
 /* 101 */ "param_list ::= LEFT_PAREN RIGHT_PAREN",
 /* 102 */ "param_list ::= LEFT_PAREN param_list_elems RIGHT_PAREN",
 /* 103 */ "param_list ::= LEFT_PAREN param_list_elems COMMA ELLIPSIS RIGHT_PAREN",
 /* 104 */ "param_list_elems ::= param_list_elems COMMA param_variable",
 /* 105 */ "param_list_elems ::= param_list_elems COMMA param_variable EQUALS scalar_constant",
 /* 106 */ "param_list_elems ::= param_variable",
 /* 107 */ "param_list_elems ::= param_variable EQUALS scalar_constant",
 /* 108 */ "qualified_id ::= IDENTIFIER",
 /* 109 */ "qualified_id ::= qualified_id SCOPE_OP IDENTIFIER",
 /* 110 */ "docucomment ::= DOCUCOMMENT",
 /* 111 */ "class_inheritance ::= INHERITS qualified_id",
 /* 112 */ "nickname ::= NICKNAME IDENTIFIER",
 /* 113 */ "cblock ::= CBLOCK_START blob CBLOCK_CLOSE",
 /* 114 */ "cblock ::= CBLOCK_START CBLOCK_CLOSE",
 /* 115 */ "blob ::= BLOB",
 /* 116 */ "blob ::= blob BLOB",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to CFCParseHeaderAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* Initialize a new parser that has already been allocated.
*/
void CFCParseHeaderInit(void *yypParser){
  yyParser *pParser = (yyParser*)yypParser;
#ifdef YYTRACKMAXSTACKDEPTH
  pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
  pParser->yytos = NULL;
  pParser->yystack = NULL;
  pParser->yystksz = 0;
  if( yyGrowStack(pParser) ){
    pParser->yystack = &pParser->yystk0;
    pParser->yystksz = 1;
  }
#endif
#ifndef YYNOERRORRECOVERY
  pParser->yyerrcnt = -1;
#endif
  pParser->yytos = pParser->yystack;
  pParser->yystack[0].stateno = 0;
  pParser->yystack[0].major = 0;
#if YYSTACKDEPTH>0
  pParser->yystackEnd = &pParser->yystack[YYSTACKDEPTH-1];
#endif
}

#ifndef CFCParseHeader_ENGINEALWAYSONSTACK
/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to CFCParseHeader and CFCParseHeaderFree.
*/
void *CFCParseHeaderAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ) CFCParseHeaderInit(pParser);
  return pParser;
}
#endif /* CFCParseHeader_ENGINEALWAYSONSTACK */


/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  CFCParseHeaderARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 44: /* result */
{
#line 237 "src/CFCParseHeader.y"

    (void)state; /* Suppress unused variable warning. */
    CFCBase_decref((CFCBase*)(yypminor->yy82));

#line 1113 "src/CFCParseHeader.c"
}
      break;
    case 45: /* file */
{
#line 241 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy51)); 
#line 1120 "src/CFCParseHeader.c"
}
      break;
    case 46: /* major_block */
    case 52: /* subroutine_declaration_statement */
{
#line 242 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy82)); 
#line 1128 "src/CFCParseHeader.c"
}
      break;
    case 47: /* parcel_definition */
{
#line 243 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy14)); 
#line 1135 "src/CFCParseHeader.c"
}
      break;
    case 48: /* class_declaration */
    case 49: /* class_head */
    case 50: /* class_defs */
{
#line 244 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy141)); 
#line 1144 "src/CFCParseHeader.c"
}
      break;
    case 51: /* var_declaration_statement */
    case 54: /* param_variable */
{
#line 247 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy57)); 
#line 1152 "src/CFCParseHeader.c"
}
      break;
    case 53: /* type */
{
#line 249 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy41)); 
#line 1159 "src/CFCParseHeader.c"
}
      break;
    case 55: /* param_list */
    case 56: /* param_list_elems */
{
#line 251 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy96)); 
#line 1167 "src/CFCParseHeader.c"
}
      break;
    case 57: /* docucomment */
{
#line 253 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy73)); 
#line 1174 "src/CFCParseHeader.c"
}
      break;
    case 58: /* cblock */
{
#line 254 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy117)); 
#line 1181 "src/CFCParseHeader.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/*
** Clear all secondary memory allocations from the parser
*/
void CFCParseHeaderFinalize(void *p){
  yyParser *pParser = (yyParser*)p;
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
}

#ifndef CFCParseHeader_ENGINEALWAYSONSTACK
/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void CFCParseHeaderFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
#ifndef YYPARSEFREENEVERNULL
  if( p==0 ) return;
#endif
  CFCParseHeaderFinalize(p);
  (*freeProc)(p);
}
#endif /* CFCParseHeader_ENGINEALWAYSONSTACK */

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int CFCParseHeaderStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/* This array of booleans keeps track of the parser statement
** coverage.  The element yycoverage[X][Y] is set when the parser
** is in state X and has a lookahead token Y.  In a well-tested
** systems, every element of this matrix should end up being set.
*/
#if defined(YYCOVERAGE)
static unsigned char yycoverage[YYNSTATE][YYNTOKEN];
#endif

/*
** Write into out a description of every state/lookahead combination that
**
**   (1)  has not been used by the parser, and
**   (2)  is not a syntax error.
**
** Return the number of missed state/lookahead combinations.
*/
#if defined(YYCOVERAGE)
int CFCParseHeaderCoverage(FILE *out){
  int stateno, iLookAhead, i;
  int nMissed = 0;
  for(stateno=0; stateno<YYNSTATE; stateno++){
    i = yy_shift_ofst[stateno];
    for(iLookAhead=0; iLookAhead<YYNTOKEN; iLookAhead++){
      if( yy_lookahead[i+iLookAhead]!=iLookAhead ) continue;
      if( yycoverage[stateno][iLookAhead]==0 ) nMissed++;
      if( out ){
        fprintf(out,"State %d lookahead %s %s\n", stateno,
                yyTokenName[iLookAhead],
                yycoverage[stateno][iLookAhead] ? "ok" : "missed");
      }
    }
  }
  return nMissed;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>YY_MAX_SHIFT ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
#if defined(YYCOVERAGE)
  yycoverage[stateno][iLookAhead] = 1;
#endif
  do{
    i = yy_shift_ofst[stateno];
    assert( i>=0 && i+YYNTOKEN<=sizeof(yy_lookahead)/sizeof(yy_lookahead[0]) );
    assert( iLookAhead!=YYNOCODE );
    assert( iLookAhead < YYNTOKEN );
    i += iLookAhead;
    if( yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   CFCParseHeaderARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState, const char *zTag){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%s%s '%s', go to state %d\n",
         yyTracePrompt, zTag, yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%s%s '%s', pending reduce %d\n",
         yyTracePrompt, zTag, yyTokenName[yypParser->yytos->major],
         yyNewState - YY_MIN_REDUCE);
    }
  }
}
#else
# define yyTraceShift(X,Y,Z)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  CFCParseHeaderTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>yypParser->yystackEnd ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState, "Shift");
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;       /* Symbol on the left-hand side of the rule */
  signed char nrhs;     /* Negative of the number of RHS symbols in the rule */
} yyRuleInfo[] = {
  {   44,   -1 }, /* (0) result ::= type */
  {   44,   -1 }, /* (1) result ::= param_list */
  {   44,   -1 }, /* (2) result ::= param_variable */
  {   44,   -1 }, /* (3) result ::= docucomment */
  {   44,   -1 }, /* (4) result ::= parcel_definition */
  {   44,   -1 }, /* (5) result ::= cblock */
  {   44,   -1 }, /* (6) result ::= var_declaration_statement */
  {   44,   -1 }, /* (7) result ::= subroutine_declaration_statement */
  {   44,   -1 }, /* (8) result ::= class_declaration */
  {   44,   -1 }, /* (9) result ::= file */
  {   45,   -2 }, /* (10) file ::= FILE_START parcel_definition */
  {   45,   -2 }, /* (11) file ::= file major_block */
  {   46,   -1 }, /* (12) major_block ::= class_declaration */
  {   46,   -1 }, /* (13) major_block ::= cblock */
  {   47,   -3 }, /* (14) parcel_definition ::= PARCEL qualified_id SEMICOLON */
  {   48,   -2 }, /* (15) class_declaration ::= class_defs RIGHT_CURLY_BRACE */
  {   49,   -7 }, /* (16) class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
  {   49,   -6 }, /* (17) class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
  {   49,   -6 }, /* (18) class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname class_inheritance */
  {   49,   -5 }, /* (19) class_head ::= declaration_modifier_list CLASS qualified_id nickname class_inheritance */
  {   49,   -6 }, /* (20) class_head ::= docucomment exposure_specifier CLASS qualified_id nickname class_inheritance */
  {   49,   -5 }, /* (21) class_head ::= exposure_specifier CLASS qualified_id nickname class_inheritance */
  {   49,   -5 }, /* (22) class_head ::= docucomment CLASS qualified_id nickname class_inheritance */
  {   49,   -4 }, /* (23) class_head ::= CLASS qualified_id nickname class_inheritance */
  {   49,   -6 }, /* (24) class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
  {   49,   -5 }, /* (25) class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
  {   49,   -5 }, /* (26) class_head ::= docucomment declaration_modifier_list CLASS qualified_id class_inheritance */
  {   49,   -4 }, /* (27) class_head ::= declaration_modifier_list CLASS qualified_id class_inheritance */
  {   49,   -5 }, /* (28) class_head ::= docucomment exposure_specifier CLASS qualified_id class_inheritance */
  {   49,   -4 }, /* (29) class_head ::= exposure_specifier CLASS qualified_id class_inheritance */
  {   49,   -4 }, /* (30) class_head ::= docucomment CLASS qualified_id class_inheritance */
  {   49,   -3 }, /* (31) class_head ::= CLASS qualified_id class_inheritance */
  {   49,   -6 }, /* (32) class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
  {   49,   -5 }, /* (33) class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
  {   49,   -5 }, /* (34) class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname */
  {   49,   -4 }, /* (35) class_head ::= declaration_modifier_list CLASS qualified_id nickname */
  {   49,   -5 }, /* (36) class_head ::= docucomment exposure_specifier CLASS qualified_id nickname */
  {   49,   -4 }, /* (37) class_head ::= exposure_specifier CLASS qualified_id nickname */
  {   49,   -4 }, /* (38) class_head ::= docucomment CLASS qualified_id nickname */
  {   49,   -3 }, /* (39) class_head ::= CLASS qualified_id nickname */
  {   49,   -5 }, /* (40) class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id */
  {   49,   -4 }, /* (41) class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id */
  {   49,   -4 }, /* (42) class_head ::= docucomment declaration_modifier_list CLASS qualified_id */
  {   49,   -3 }, /* (43) class_head ::= declaration_modifier_list CLASS qualified_id */
  {   49,   -4 }, /* (44) class_head ::= docucomment exposure_specifier CLASS qualified_id */
  {   49,   -3 }, /* (45) class_head ::= exposure_specifier CLASS qualified_id */
  {   49,   -3 }, /* (46) class_head ::= docucomment CLASS qualified_id */
  {   49,   -2 }, /* (47) class_head ::= CLASS qualified_id */
  {   50,   -2 }, /* (48) class_defs ::= class_head LEFT_CURLY_BRACE */
  {   50,   -2 }, /* (49) class_defs ::= class_defs var_declaration_statement */
  {   50,   -2 }, /* (50) class_defs ::= class_defs subroutine_declaration_statement */
  {   51,   -3 }, /* (51) var_declaration_statement ::= type declarator SEMICOLON */
  {   51,   -4 }, /* (52) var_declaration_statement ::= declaration_modifier_list type declarator SEMICOLON */
  {   51,   -5 }, /* (53) var_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator SEMICOLON */
  {   52,   -4 }, /* (54) subroutine_declaration_statement ::= type declarator param_list SEMICOLON */
  {   52,   -5 }, /* (55) subroutine_declaration_statement ::= declaration_modifier_list type declarator param_list SEMICOLON */
  {   52,   -6 }, /* (56) subroutine_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
  {   52,   -5 }, /* (57) subroutine_declaration_statement ::= exposure_specifier type declarator param_list SEMICOLON */
  {   52,   -5 }, /* (58) subroutine_declaration_statement ::= docucomment type declarator param_list SEMICOLON */
  {   52,   -6 }, /* (59) subroutine_declaration_statement ::= docucomment declaration_modifier_list type declarator param_list SEMICOLON */
  {   52,   -7 }, /* (60) subroutine_declaration_statement ::= docucomment exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
  {   52,   -6 }, /* (61) subroutine_declaration_statement ::= docucomment exposure_specifier type declarator param_list SEMICOLON */
  {   53,   -1 }, /* (62) type ::= type_name */
  {   53,   -2 }, /* (63) type ::= type_name asterisk_postfix */
  {   53,   -2 }, /* (64) type ::= type_name array_postfix */
  {   53,   -2 }, /* (65) type ::= type_qualifier_list type_name */
  {   53,   -3 }, /* (66) type ::= type_qualifier_list type_name asterisk_postfix */
  {   53,   -3 }, /* (67) type ::= type_qualifier_list type_name array_postfix */
  {   67,   -1 }, /* (68) type_name ::= VOID */
  {   67,   -1 }, /* (69) type_name ::= VA_LIST */
  {   67,   -1 }, /* (70) type_name ::= INTEGER_TYPE_NAME */
  {   67,   -1 }, /* (71) type_name ::= FLOAT_TYPE_NAME */
  {   67,   -1 }, /* (72) type_name ::= IDENTIFIER */
  {   62,   -1 }, /* (73) exposure_specifier ::= PUBLIC */
  {   59,   -1 }, /* (74) type_qualifier ::= CONST */
  {   59,   -1 }, /* (75) type_qualifier ::= NULLABLE */
  {   59,   -1 }, /* (76) type_qualifier ::= INCREMENTED */
  {   59,   -1 }, /* (77) type_qualifier ::= DECREMENTED */
  {   60,   -1 }, /* (78) type_qualifier_list ::= type_qualifier */
  {   60,   -2 }, /* (79) type_qualifier_list ::= type_qualifier_list type_qualifier */
  {   70,   -1 }, /* (80) declaration_modifier ::= INERT */
  {   70,   -1 }, /* (81) declaration_modifier ::= INLINE */
  {   70,   -1 }, /* (82) declaration_modifier ::= ABSTRACT */
  {   70,   -1 }, /* (83) declaration_modifier ::= FINAL */
  {   63,   -1 }, /* (84) declaration_modifier_list ::= declaration_modifier */
  {   63,   -2 }, /* (85) declaration_modifier_list ::= declaration_modifier_list declaration_modifier */
  {   68,   -1 }, /* (86) asterisk_postfix ::= ASTERISK */
  {   68,   -2 }, /* (87) asterisk_postfix ::= asterisk_postfix ASTERISK */
  {   71,   -2 }, /* (88) array_postfix_elem ::= LEFT_SQUARE_BRACKET RIGHT_SQUARE_BRACKET */
  {   71,   -3 }, /* (89) array_postfix_elem ::= LEFT_SQUARE_BRACKET INTEGER_LITERAL RIGHT_SQUARE_BRACKET */
  {   69,   -1 }, /* (90) array_postfix ::= array_postfix_elem */
  {   69,   -2 }, /* (91) array_postfix ::= array_postfix array_postfix_elem */
  {   72,   -1 }, /* (92) scalar_constant ::= HEX_LITERAL */
  {   72,   -1 }, /* (93) scalar_constant ::= FLOAT_LITERAL */
  {   72,   -1 }, /* (94) scalar_constant ::= INTEGER_LITERAL */
  {   72,   -1 }, /* (95) scalar_constant ::= STRING_LITERAL */
  {   72,   -1 }, /* (96) scalar_constant ::= TRUE */
  {   72,   -1 }, /* (97) scalar_constant ::= FALSE */
  {   72,   -1 }, /* (98) scalar_constant ::= NULL */
  {   66,   -1 }, /* (99) declarator ::= IDENTIFIER */
  {   54,   -2 }, /* (100) param_variable ::= type declarator */
  {   55,   -2 }, /* (101) param_list ::= LEFT_PAREN RIGHT_PAREN */
  {   55,   -3 }, /* (102) param_list ::= LEFT_PAREN param_list_elems RIGHT_PAREN */
  {   55,   -5 }, /* (103) param_list ::= LEFT_PAREN param_list_elems COMMA ELLIPSIS RIGHT_PAREN */
  {   56,   -3 }, /* (104) param_list_elems ::= param_list_elems COMMA param_variable */
  {   56,   -5 }, /* (105) param_list_elems ::= param_list_elems COMMA param_variable EQUALS scalar_constant */
  {   56,   -1 }, /* (106) param_list_elems ::= param_variable */
  {   56,   -3 }, /* (107) param_list_elems ::= param_variable EQUALS scalar_constant */
  {   61,   -1 }, /* (108) qualified_id ::= IDENTIFIER */
  {   61,   -3 }, /* (109) qualified_id ::= qualified_id SCOPE_OP IDENTIFIER */
  {   57,   -1 }, /* (110) docucomment ::= DOCUCOMMENT */
  {   65,   -2 }, /* (111) class_inheritance ::= INHERITS qualified_id */
  {   64,   -2 }, /* (112) nickname ::= NICKNAME IDENTIFIER */
  {   58,   -3 }, /* (113) cblock ::= CBLOCK_START blob CBLOCK_CLOSE */
  {   58,   -2 }, /* (114) cblock ::= CBLOCK_START CBLOCK_CLOSE */
  {   73,   -1 }, /* (115) blob ::= BLOB */
  {   73,   -2 }, /* (116) blob ::= blob BLOB */
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
**
** The yyLookahead and yyLookaheadToken parameters provide reduce actions
** access to the lookahead token (if any).  The yyLookahead will be YYNOCODE
** if the lookahead token has already been consumed.  As this procedure is
** only called from one place, optimizing compilers will in-line it, which
** means that the extra parameters have no performance impact.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno,       /* Number of the rule by which to reduce */
  int yyLookahead,             /* Lookahead token, or YYNOCODE if none */
  CFCParseHeaderTOKENTYPE yyLookaheadToken  /* Value of the lookahead token */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  CFCParseHeaderARG_FETCH;
  (void)yyLookahead;
  (void)yyLookaheadToken;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    if( yysize ){
      fprintf(yyTraceFILE, "%sReduce %d [%s], go to state %d.\n",
        yyTracePrompt,
        yyruleno, yyRuleName[yyruleno], yymsp[yysize].stateno);
    }else{
      fprintf(yyTraceFILE, "%sReduce %d [%s].\n",
        yyTracePrompt, yyruleno, yyRuleName[yyruleno]);
    }
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=yypParser->yystackEnd ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* result ::= type */
#line 257 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy41);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy41);
}
#line 1677 "src/CFCParseHeader.c"
        break;
      case 1: /* result ::= param_list */
#line 262 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy96);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy96);
}
#line 1685 "src/CFCParseHeader.c"
        break;
      case 2: /* result ::= param_variable */
      case 6: /* result ::= var_declaration_statement */ yytestcase(yyruleno==6);
#line 267 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy57);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 1694 "src/CFCParseHeader.c"
        break;
      case 3: /* result ::= docucomment */
#line 272 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy73);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy73);
}
#line 1702 "src/CFCParseHeader.c"
        break;
      case 4: /* result ::= parcel_definition */
#line 277 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy14);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy14);
}
#line 1710 "src/CFCParseHeader.c"
        break;
      case 5: /* result ::= cblock */
#line 282 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy117);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy117);
}
#line 1718 "src/CFCParseHeader.c"
        break;
      case 7: /* result ::= subroutine_declaration_statement */
#line 292 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy82);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 1726 "src/CFCParseHeader.c"
        break;
      case 8: /* result ::= class_declaration */
#line 297 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy141);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy141);
}
#line 1734 "src/CFCParseHeader.c"
        break;
      case 9: /* result ::= file */
#line 302 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy51);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy51);
}
#line 1742 "src/CFCParseHeader.c"
        break;
      case 10: /* file ::= FILE_START parcel_definition */
#line 309 "src/CFCParseHeader.y"
{
    yymsp[-1].minor.yy51 = CFCFile_new(yymsp[0].minor.yy14, CFCParser_get_file_spec(state));
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy14);
}
#line 1750 "src/CFCParseHeader.c"
        break;
      case 11: /* file ::= file major_block */
#line 314 "src/CFCParseHeader.y"
{
    yylhsminor.yy51 = yymsp[-1].minor.yy51;
    CFCFile_add_block(yylhsminor.yy51, yymsp[0].minor.yy82);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 1759 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy51 = yylhsminor.yy51;
        break;
      case 12: /* major_block ::= class_declaration */
#line 320 "src/CFCParseHeader.y"
{ yylhsminor.yy82 = (CFCBase*)yymsp[0].minor.yy141; }
#line 1765 "src/CFCParseHeader.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 13: /* major_block ::= cblock */
#line 321 "src/CFCParseHeader.y"
{ yylhsminor.yy82 = (CFCBase*)yymsp[0].minor.yy117; }
#line 1771 "src/CFCParseHeader.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 14: /* parcel_definition ::= PARCEL qualified_id SEMICOLON */
#line 324 "src/CFCParseHeader.y"
{
    yymsp[-2].minor.yy14 = CFCParcel_fetch(yymsp[-1].minor.yy0);
    if (!yymsp[-2].minor.yy14) {
        /* Allow unregistered parcels to simplify tests. */
        yymsp[-2].minor.yy14 = CFCParcel_new(yymsp[-1].minor.yy0, NULL, NULL, NULL, NULL);
        CFCParcel_register(yymsp[-2].minor.yy14);
    }
    else {
        CFCBase_incref((CFCBase*)yymsp[-2].minor.yy14);
    }
    CFCParser_set_parcel(state, yymsp[-2].minor.yy14);
}
#line 1788 "src/CFCParseHeader.c"
        break;
      case 15: /* class_declaration ::= class_defs RIGHT_CURLY_BRACE */
#line 338 "src/CFCParseHeader.y"
{
    yylhsminor.yy141 = yymsp[-1].minor.yy141;
    CFCParser_set_class_name(state, NULL);
}
#line 1796 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy141 = yylhsminor.yy141;
        break;
      case 16: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 343 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-6].minor.yy73,    yymsp[-5].minor.yy0,    yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1802 "src/CFCParseHeader.c"
  yymsp[-6].minor.yy141 = yylhsminor.yy141;
        break;
      case 17: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 344 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-5].minor.yy0,    yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1808 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy141 = yylhsminor.yy141;
        break;
      case 18: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 345 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    NULL, yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1814 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy141 = yylhsminor.yy141;
        break;
      case 19: /* class_head ::= declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 346 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, NULL, yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1820 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 20: /* class_head ::= docucomment exposure_specifier CLASS qualified_id nickname class_inheritance */
#line 347 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1826 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy141 = yylhsminor.yy141;
        break;
      case 21: /* class_head ::= exposure_specifier CLASS qualified_id nickname class_inheritance */
#line 348 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1832 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 22: /* class_head ::= docucomment CLASS qualified_id nickname class_inheritance */
#line 349 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1838 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 23: /* class_head ::= CLASS qualified_id nickname class_inheritance */
#line 350 "src/CFCParseHeader.y"
{ yymsp[-3].minor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1844 "src/CFCParseHeader.c"
        break;
      case 24: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
#line 351 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1849 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy141 = yylhsminor.yy141;
        break;
      case 25: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
#line 352 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1855 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 26: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id class_inheritance */
#line 353 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1861 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 27: /* class_head ::= declaration_modifier_list CLASS qualified_id class_inheritance */
#line 354 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1867 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 28: /* class_head ::= docucomment exposure_specifier CLASS qualified_id class_inheritance */
#line 355 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1873 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 29: /* class_head ::= exposure_specifier CLASS qualified_id class_inheritance */
#line 356 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1879 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 30: /* class_head ::= docucomment CLASS qualified_id class_inheritance */
#line 357 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1885 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 31: /* class_head ::= CLASS qualified_id class_inheritance */
#line 358 "src/CFCParseHeader.y"
{ yymsp[-2].minor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1891 "src/CFCParseHeader.c"
        break;
      case 32: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
#line 359 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1896 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy141 = yylhsminor.yy141;
        break;
      case 33: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
#line 360 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1902 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 34: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname */
#line 361 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1908 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 35: /* class_head ::= declaration_modifier_list CLASS qualified_id nickname */
#line 362 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1914 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 36: /* class_head ::= docucomment exposure_specifier CLASS qualified_id nickname */
#line 363 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1920 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 37: /* class_head ::= exposure_specifier CLASS qualified_id nickname */
#line 364 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1926 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 38: /* class_head ::= docucomment CLASS qualified_id nickname */
#line 365 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1932 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 39: /* class_head ::= CLASS qualified_id nickname */
#line 366 "src/CFCParseHeader.y"
{ yymsp[-2].minor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1938 "src/CFCParseHeader.c"
        break;
      case 40: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id */
#line 367 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1943 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy141 = yylhsminor.yy141;
        break;
      case 41: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id */
#line 368 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1949 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 42: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id */
#line 369 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1955 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 43: /* class_head ::= declaration_modifier_list CLASS qualified_id */
#line 370 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, NULL, yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1961 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy141 = yylhsminor.yy141;
        break;
      case 44: /* class_head ::= docucomment exposure_specifier CLASS qualified_id */
#line 371 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    yymsp[-2].minor.yy0,    NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1967 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy141 = yylhsminor.yy141;
        break;
      case 45: /* class_head ::= exposure_specifier CLASS qualified_id */
#line 372 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, NULL, yymsp[-2].minor.yy0,    NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1973 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy141 = yylhsminor.yy141;
        break;
      case 46: /* class_head ::= docucomment CLASS qualified_id */
#line 373 "src/CFCParseHeader.y"
{ yylhsminor.yy141 = S_start_class(state, yymsp[-2].minor.yy73,    NULL, NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1979 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy141 = yylhsminor.yy141;
        break;
      case 47: /* class_head ::= CLASS qualified_id */
#line 374 "src/CFCParseHeader.y"
{ yymsp[-1].minor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1985 "src/CFCParseHeader.c"
        break;
      case 48: /* class_defs ::= class_head LEFT_CURLY_BRACE */
#line 377 "src/CFCParseHeader.y"
{
    yylhsminor.yy141 = yymsp[-1].minor.yy141;
}
#line 1992 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy141 = yylhsminor.yy141;
        break;
      case 49: /* class_defs ::= class_defs var_declaration_statement */
#line 381 "src/CFCParseHeader.y"
{
    yylhsminor.yy141 = yymsp[-1].minor.yy141;
    if (CFCVariable_inert(yymsp[0].minor.yy57)) {
        CFCClass_add_inert_var(yylhsminor.yy141, yymsp[0].minor.yy57);
    }
    else {
        CFCClass_add_member_var(yylhsminor.yy141, yymsp[0].minor.yy57);
    }
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 2007 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy141 = yylhsminor.yy141;
        break;
      case 50: /* class_defs ::= class_defs subroutine_declaration_statement */
#line 392 "src/CFCParseHeader.y"
{
    yylhsminor.yy141 = yymsp[-1].minor.yy141;
    if (strcmp(CFCBase_get_cfc_class(yymsp[0].minor.yy82), "Clownfish::CFC::Model::Function") == 0) {
        CFCClass_add_function(yylhsminor.yy141, (CFCFunction*)yymsp[0].minor.yy82);
    }
    else {
        CFCClass_add_method(yylhsminor.yy141, (CFCMethod*)yymsp[0].minor.yy82);
    }
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 2022 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy141 = yylhsminor.yy141;
        break;
      case 51: /* var_declaration_statement ::= type declarator SEMICOLON */
#line 405 "src/CFCParseHeader.y"
{
    yylhsminor.yy57 = S_new_var(CFCParser_dupe(state, "private"), NULL, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 2030 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy57 = yylhsminor.yy57;
        break;
      case 52: /* var_declaration_statement ::= declaration_modifier_list type declarator SEMICOLON */
#line 411 "src/CFCParseHeader.y"
{
    yylhsminor.yy57 = S_new_var(CFCParser_dupe(state, "parcel"), yymsp[-3].minor.yy0, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 2038 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy57 = yylhsminor.yy57;
        break;
      case 53: /* var_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator SEMICOLON */
#line 418 "src/CFCParseHeader.y"
{
    yylhsminor.yy57 = S_new_var(yymsp[-4].minor.yy0, yymsp[-3].minor.yy0, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 2046 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy57 = yylhsminor.yy57;
        break;
      case 54: /* subroutine_declaration_statement ::= type declarator param_list SEMICOLON */
#line 424 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, NULL, NULL, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2054 "src/CFCParseHeader.c"
  yymsp[-3].minor.yy82 = yylhsminor.yy82;
        break;
      case 55: /* subroutine_declaration_statement ::= declaration_modifier_list type declarator param_list SEMICOLON */
#line 430 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, NULL, NULL, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2062 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 56: /* subroutine_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
#line 437 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, NULL, yymsp[-5].minor.yy0, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2070 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy82 = yylhsminor.yy82;
        break;
      case 57: /* subroutine_declaration_statement ::= exposure_specifier type declarator param_list SEMICOLON */
#line 443 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, NULL, yymsp[-4].minor.yy0, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2078 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 58: /* subroutine_declaration_statement ::= docucomment type declarator param_list SEMICOLON */
#line 449 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, yymsp[-4].minor.yy73, NULL, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2086 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 59: /* subroutine_declaration_statement ::= docucomment declaration_modifier_list type declarator param_list SEMICOLON */
#line 456 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, yymsp[-5].minor.yy73, NULL, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2094 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy82 = yylhsminor.yy82;
        break;
      case 60: /* subroutine_declaration_statement ::= docucomment exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
#line 464 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, yymsp[-6].minor.yy73, yymsp[-5].minor.yy0, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2102 "src/CFCParseHeader.c"
  yymsp[-6].minor.yy82 = yylhsminor.yy82;
        break;
      case 61: /* subroutine_declaration_statement ::= docucomment exposure_specifier type declarator param_list SEMICOLON */
#line 471 "src/CFCParseHeader.y"
{
    yylhsminor.yy82 = S_new_sub(state, yymsp[-5].minor.yy73, yymsp[-4].minor.yy0, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 2110 "src/CFCParseHeader.c"
  yymsp[-5].minor.yy82 = yylhsminor.yy82;
        break;
      case 62: /* type ::= type_name */
#line 476 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, 0, yymsp[0].minor.yy0, NULL, NULL);
}
#line 2118 "src/CFCParseHeader.c"
  yymsp[0].minor.yy41 = yylhsminor.yy41;
        break;
      case 63: /* type ::= type_name asterisk_postfix */
#line 480 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, 0, yymsp[-1].minor.yy0, yymsp[0].minor.yy0, NULL);
}
#line 2126 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy41 = yylhsminor.yy41;
        break;
      case 64: /* type ::= type_name array_postfix */
#line 484 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, 0, yymsp[-1].minor.yy0, NULL, yymsp[0].minor.yy0);
}
#line 2134 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy41 = yylhsminor.yy41;
        break;
      case 65: /* type ::= type_qualifier_list type_name */
#line 488 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, yymsp[-1].minor.yy8, yymsp[0].minor.yy0, NULL, NULL);
}
#line 2142 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy41 = yylhsminor.yy41;
        break;
      case 66: /* type ::= type_qualifier_list type_name asterisk_postfix */
#line 492 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, yymsp[-2].minor.yy8, yymsp[-1].minor.yy0, yymsp[0].minor.yy0, NULL);
}
#line 2150 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy41 = yylhsminor.yy41;
        break;
      case 67: /* type ::= type_qualifier_list type_name array_postfix */
#line 496 "src/CFCParseHeader.y"
{
    yylhsminor.yy41 = S_new_type(state, yymsp[-2].minor.yy8, yymsp[-1].minor.yy0, NULL, yymsp[0].minor.yy0);
}
#line 2158 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy41 = yylhsminor.yy41;
        break;
      case 68: /* type_name ::= VOID */
      case 69: /* type_name ::= VA_LIST */ yytestcase(yyruleno==69);
      case 70: /* type_name ::= INTEGER_TYPE_NAME */ yytestcase(yyruleno==70);
      case 71: /* type_name ::= FLOAT_TYPE_NAME */ yytestcase(yyruleno==71);
      case 72: /* type_name ::= IDENTIFIER */ yytestcase(yyruleno==72);
      case 73: /* exposure_specifier ::= PUBLIC */ yytestcase(yyruleno==73);
      case 80: /* declaration_modifier ::= INERT */ yytestcase(yyruleno==80);
      case 81: /* declaration_modifier ::= INLINE */ yytestcase(yyruleno==81);
      case 82: /* declaration_modifier ::= ABSTRACT */ yytestcase(yyruleno==82);
      case 83: /* declaration_modifier ::= FINAL */ yytestcase(yyruleno==83);
      case 84: /* declaration_modifier_list ::= declaration_modifier */ yytestcase(yyruleno==84);
      case 86: /* asterisk_postfix ::= ASTERISK */ yytestcase(yyruleno==86);
      case 90: /* array_postfix ::= array_postfix_elem */ yytestcase(yyruleno==90);
      case 92: /* scalar_constant ::= HEX_LITERAL */ yytestcase(yyruleno==92);
      case 93: /* scalar_constant ::= FLOAT_LITERAL */ yytestcase(yyruleno==93);
      case 94: /* scalar_constant ::= INTEGER_LITERAL */ yytestcase(yyruleno==94);
      case 95: /* scalar_constant ::= STRING_LITERAL */ yytestcase(yyruleno==95);
      case 96: /* scalar_constant ::= TRUE */ yytestcase(yyruleno==96);
      case 97: /* scalar_constant ::= FALSE */ yytestcase(yyruleno==97);
      case 98: /* scalar_constant ::= NULL */ yytestcase(yyruleno==98);
      case 108: /* qualified_id ::= IDENTIFIER */ yytestcase(yyruleno==108);
      case 115: /* blob ::= BLOB */ yytestcase(yyruleno==115);
#line 500 "src/CFCParseHeader.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 2185 "src/CFCParseHeader.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 74: /* type_qualifier ::= CONST */
#line 508 "src/CFCParseHeader.y"
{ yymsp[0].minor.yy8 = CFCTYPE_CONST; }
#line 2191 "src/CFCParseHeader.c"
        break;
      case 75: /* type_qualifier ::= NULLABLE */
#line 509 "src/CFCParseHeader.y"
{ yymsp[0].minor.yy8 = CFCTYPE_NULLABLE; }
#line 2196 "src/CFCParseHeader.c"
        break;
      case 76: /* type_qualifier ::= INCREMENTED */
#line 510 "src/CFCParseHeader.y"
{ yymsp[0].minor.yy8 = CFCTYPE_INCREMENTED; }
#line 2201 "src/CFCParseHeader.c"
        break;
      case 77: /* type_qualifier ::= DECREMENTED */
#line 511 "src/CFCParseHeader.y"
{ yymsp[0].minor.yy8 = CFCTYPE_DECREMENTED; }
#line 2206 "src/CFCParseHeader.c"
        break;
      case 78: /* type_qualifier_list ::= type_qualifier */
#line 514 "src/CFCParseHeader.y"
{
    yylhsminor.yy8 = yymsp[0].minor.yy8;
}
#line 2213 "src/CFCParseHeader.c"
  yymsp[0].minor.yy8 = yylhsminor.yy8;
        break;
      case 79: /* type_qualifier_list ::= type_qualifier_list type_qualifier */
#line 518 "src/CFCParseHeader.y"
{
    yylhsminor.yy8 = yymsp[-1].minor.yy8;
    yylhsminor.yy8 |= yymsp[0].minor.yy8;
}
#line 2222 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy8 = yylhsminor.yy8;
        break;
      case 85: /* declaration_modifier_list ::= declaration_modifier_list declaration_modifier */
#line 530 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + strlen(yymsp[0].minor.yy0) + 2;
    yylhsminor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yylhsminor.yy0, "%s %s", yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
}
#line 2232 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 87: /* asterisk_postfix ::= asterisk_postfix ASTERISK */
#line 538 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + 2;
    yylhsminor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yylhsminor.yy0, "%s*", yymsp[-1].minor.yy0);
}
#line 2242 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 88: /* array_postfix_elem ::= LEFT_SQUARE_BRACKET RIGHT_SQUARE_BRACKET */
#line 545 "src/CFCParseHeader.y"
{
    yymsp[-1].minor.yy0 = CFCParser_dupe(state, "[]");
}
#line 2250 "src/CFCParseHeader.c"
        break;
      case 89: /* array_postfix_elem ::= LEFT_SQUARE_BRACKET INTEGER_LITERAL RIGHT_SQUARE_BRACKET */
#line 549 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + 3;
    yymsp[-2].minor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yymsp[-2].minor.yy0, "[%s]", yymsp[-1].minor.yy0);
}
#line 2259 "src/CFCParseHeader.c"
        break;
      case 91: /* array_postfix ::= array_postfix array_postfix_elem */
      case 116: /* blob ::= blob BLOB */ yytestcase(yyruleno==116);
#line 557 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + strlen(yymsp[0].minor.yy0) + 1;
    yylhsminor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yylhsminor.yy0, "%s%s", yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
}
#line 2269 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 99: /* declarator ::= IDENTIFIER */
#line 572 "src/CFCParseHeader.y"
{
    yylhsminor.yy0 = yymsp[0].minor.yy0;
}
#line 2277 "src/CFCParseHeader.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 100: /* param_variable ::= type declarator */
#line 577 "src/CFCParseHeader.y"
{
    yylhsminor.yy57 = S_new_var(NULL, NULL, yymsp[-1].minor.yy41, yymsp[0].minor.yy0);
}
#line 2285 "src/CFCParseHeader.c"
  yymsp[-1].minor.yy57 = yylhsminor.yy57;
        break;
      case 101: /* param_list ::= LEFT_PAREN RIGHT_PAREN */
#line 582 "src/CFCParseHeader.y"
{
    yymsp[-1].minor.yy96 = CFCParamList_new(false);
}
#line 2293 "src/CFCParseHeader.c"
        break;
      case 102: /* param_list ::= LEFT_PAREN param_list_elems RIGHT_PAREN */
#line 586 "src/CFCParseHeader.y"
{
    yymsp[-2].minor.yy96 = yymsp[-1].minor.yy96;
}
#line 2300 "src/CFCParseHeader.c"
        break;
      case 103: /* param_list ::= LEFT_PAREN param_list_elems COMMA ELLIPSIS RIGHT_PAREN */
#line 590 "src/CFCParseHeader.y"
{
    yymsp[-4].minor.yy96 = yymsp[-3].minor.yy96;
    CFCParamList_set_variadic(yymsp[-4].minor.yy96, true);
}
#line 2308 "src/CFCParseHeader.c"
        break;
      case 104: /* param_list_elems ::= param_list_elems COMMA param_variable */
#line 595 "src/CFCParseHeader.y"
{
    yylhsminor.yy96 = yymsp[-2].minor.yy96;
    CFCParamList_add_param(yylhsminor.yy96, yymsp[0].minor.yy57, NULL);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 2317 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy96 = yylhsminor.yy96;
        break;
      case 105: /* param_list_elems ::= param_list_elems COMMA param_variable EQUALS scalar_constant */
#line 601 "src/CFCParseHeader.y"
{
    yylhsminor.yy96 = yymsp[-4].minor.yy96;
    CFCParamList_add_param(yylhsminor.yy96, yymsp[-2].minor.yy57, yymsp[0].minor.yy0);
    CFCBase_decref((CFCBase*)yymsp[-2].minor.yy57);
}
#line 2327 "src/CFCParseHeader.c"
  yymsp[-4].minor.yy96 = yylhsminor.yy96;
        break;
      case 106: /* param_list_elems ::= param_variable */
#line 607 "src/CFCParseHeader.y"
{
    yylhsminor.yy96 = CFCParamList_new(false);
    CFCParamList_add_param(yylhsminor.yy96, yymsp[0].minor.yy57, NULL);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 2337 "src/CFCParseHeader.c"
  yymsp[0].minor.yy96 = yylhsminor.yy96;
        break;
      case 107: /* param_list_elems ::= param_variable EQUALS scalar_constant */
#line 613 "src/CFCParseHeader.y"
{
    yylhsminor.yy96 = CFCParamList_new(false);
    CFCParamList_add_param(yylhsminor.yy96, yymsp[-2].minor.yy57, yymsp[0].minor.yy0);
    CFCBase_decref((CFCBase*)yymsp[-2].minor.yy57);
}
#line 2347 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy96 = yylhsminor.yy96;
        break;
      case 109: /* qualified_id ::= qualified_id SCOPE_OP IDENTIFIER */
#line 621 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-2].minor.yy0) + strlen(yymsp[0].minor.yy0) + 3;
    yylhsminor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yylhsminor.yy0, "%s::%s", yymsp[-2].minor.yy0, yymsp[0].minor.yy0);
}
#line 2357 "src/CFCParseHeader.c"
  yymsp[-2].minor.yy0 = yylhsminor.yy0;
        break;
      case 110: /* docucomment ::= DOCUCOMMENT */
#line 627 "src/CFCParseHeader.y"
{ yylhsminor.yy73 = CFCDocuComment_parse(yymsp[0].minor.yy0); }
#line 2363 "src/CFCParseHeader.c"
  yymsp[0].minor.yy73 = yylhsminor.yy73;
        break;
      case 111: /* class_inheritance ::= INHERITS qualified_id */
      case 112: /* nickname ::= NICKNAME IDENTIFIER */ yytestcase(yyruleno==112);
#line 628 "src/CFCParseHeader.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 2370 "src/CFCParseHeader.c"
        break;
      case 113: /* cblock ::= CBLOCK_START blob CBLOCK_CLOSE */
#line 630 "src/CFCParseHeader.y"
{ yymsp[-2].minor.yy117 = CFCCBlock_new(yymsp[-1].minor.yy0); }
#line 2375 "src/CFCParseHeader.c"
        break;
      case 114: /* cblock ::= CBLOCK_START CBLOCK_CLOSE */
#line 631 "src/CFCParseHeader.y"
{ yymsp[-1].minor.yy117 = CFCCBlock_new(""); }
#line 2380 "src/CFCParseHeader.c"
        break;
      default:
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[yysize].stateno,(YYCODETYPE)yygoto);

  /* There are no SHIFTREDUCE actions on nonterminals because the table
  ** generator has simplified them to pure REDUCE actions. */
  assert( !(yyact>YY_MAX_SHIFT && yyact<=YY_MAX_SHIFTREDUCE) );

  /* It is not possible for a REDUCE to be followed by an error */
  assert( yyact!=YY_ERROR_ACTION );

  yymsp += yysize+1;
  yypParser->yytos = yymsp;
  yymsp->stateno = (YYACTIONTYPE)yyact;
  yymsp->major = (YYCODETYPE)yygoto;
  yyTraceShift(yypParser, yyact, "... then shift");
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  CFCParseHeaderARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  CFCParseHeaderTOKENTYPE yyminor         /* The minor type of the error token */
){
  CFCParseHeaderARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 212 "src/CFCParseHeader.y"

    (void)yymajor;
    (void)yyminor;
    CFCParser_set_errors(state, true);
    CFCParser_set_lineno(state, yyget_lineno());
#line 2444 "src/CFCParseHeader.c"
/************ End %syntax_error code ******************************************/
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  CFCParseHeaderARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "CFCParseHeaderAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void CFCParseHeader(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  CFCParseHeaderTOKENTYPE yyminor       /* The value for the token */
  CFCParseHeaderARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  CFCParseHeaderARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    int stateno = yypParser->yytos->stateno;
    if( stateno < YY_MIN_REDUCE ){
      fprintf(yyTraceFILE,"%sInput '%s' in state %d\n",
              yyTracePrompt,yyTokenName[yymajor],stateno);
    }else{
      fprintf(yyTraceFILE,"%sInput '%s' with pending reduce %d\n",
              yyTracePrompt,yyTokenName[yymajor],stateno-YY_MIN_REDUCE);
    }
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact >= YY_MIN_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE,yymajor,yyminor);
    }else if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact==YY_ACCEPT_ACTION ){
      yypParser->yytos--;
      yy_accept(yypParser);
      return;
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
